import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {CommonsService} from '../../../services/commons.service';
import {CompanyService} from '../../../services/company.service';
import {environment} from '../../../../environments/environment';

@Component({
  selector: 'app-company-list',
  templateUrl: './company-list.component.html',
  styleUrls: ['./company-list.component.scss']
})
export class CompanyListComponent implements OnInit {
  WEB_SERVE_URL = environment.imageUrl;
  searchForm: FormGroup; // 搜索框
  requestData = []; // 列表数据
  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;

  constructor(
      private form: FormBuilder,
      private company: CompanyService,
      private iconService: IconService,
      private message: NzMessageService,
      private router: Router,
      private common: CommonsService
  ) {
  }

  ngOnInit(): void {
    this.init();
  }

  public init(): void {
    this.searchForm = this.form.group({
      name: [null],
      status: [null],
    });
    this.getRequest(true, this.searchForm.value);
  }

  // 查询列表
  public getRequest(reset: boolean = false, whereObject: object) {

    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    this.company.selectCompanyList(whereObject, data => {
      if (data['return_code'] === '000000') {
        this.requestData = data['return_data'].list;
        this.total = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

  public getForbiddenUser(id, status: any): void {
    const message = (status === 1 ? '是否禁用当前公司' : '是否启用当前公司');

    const s = status === 1 ? 0 : 1;

    this.common.showConfirm(message, data => {
      if (data) {
        this.company.editStatus(id, s , dataUser => {
          this.getRequest(false , this.searchForm.value);
        });
      }
    });
  }


  // 修改
  public getEdit(id: number): void {
    this.router.navigate(['/admin/company/company-edit'], {
      queryParams: {
        companyId: id
      }
    }).then(r => console.log(r));
  }

  // 查看详情
  public getDetail(id: number): void {
    this.router.navigate(['/admin/company/company-detail'], {
      queryParams: {
        companyId: id
      }
    }).then(r => console.log(r));
  }


}

