import { Component, OnInit } from '@angular/core';
import {environment} from '../../../../environments/environment';
import {FormBuilder, FormGroup} from '@angular/forms';
import {MerchantService} from '../../../services/merchant.service';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {SystemService} from '../../../services/system.service';

@Component({
  selector: 'app-sinopec-config',
  templateUrl: './sinopec-config.component.html',
  styleUrls: ['./sinopec-config.component.scss']
})
export class SinopecConfigComponent implements OnInit {

  WEB_SERVE_URL = environment.imageUrl;
  searchForm: FormGroup; // 搜索框
  requestData = []; // 列表数据
  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;

  constructor(
      private form: FormBuilder,
      private system: SystemService,
      private iconService: IconService,
      private message: NzMessageService,
      private router: Router,
  ) {
  }

  ngOnInit(): void {
    this.init();
  }

  public init(): void {
    this.searchForm = this.form.group({
      merchantKey: [null],
      merchantName: [null],
      telephone: [null],
      status: [null],
    });
    this.getRequest(true, this.searchForm.value);
  }

  // 查询列表
  public getRequest(reset: boolean = false, whereObject: object) {

    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    this.system.getListSinopecConfig(whereObject, data => {
      if (data['return_code'] === '000000') {
        this.requestData = data['return_data'].list;
        this.total = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

  // 修改
  public getEdit(id: number): void {
    this.router.navigate(['/admin/system/sinopec-edit'], {
      queryParams: {
        sinopecId: id
      }
    }).then(r => console.log(r));
  }

  // // 查看详情
  // public getDetail(id: number): void {
  //   this.router.navigate(['/admin/system/sinopec-detail'], {
  //     queryParams: {
  //       merchantId: id
  //     }
  //   }).then(r => console.log(r));
  // }

}
